#!/bin/bash
#
# buildCry.sh 

# if this build script complains that it cannot find bzlib.h, 
# you need to install bzip2-devel on Scientific Linux

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e14|e15|e17|c2> <debug|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}


# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
extraqual=${3}
maketar=${4}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=cry
origpkgver=v1_7
pkgver=${origpkgver}k
ssibuildshims_version=v1_04_02
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=cry_v${pkgdotver}

get_this_dir

get_ssibuildshims

source define_basics --

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

if [ "${extraqual}" = "debug" ]
then
    local_make=Makefile.local.debug
elif [ "${extraqual}" = "prof" ]
then
    local_make=Makefile.local.prof
fi

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

setup -B ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "ERROR: fake setup failed"

set -x

cd ${pkgdir}
tar xzf ${tardir}/${pkgtarname}.tar.gz

# apply Fermi patches
patch -b -p0 < ${patchdir}/${pkgtarname}.patch || ssi_die "ERROR: Unable to apply patch."

# extra instructions are in Makefile.local
cp ${patchdir}/${local_make} ${CRYHOME}/Makefile.local
if [[ "${basequal}" == e1[0245SS] ]]; then
  cc=gcc
  cxx=g++
  echo "CXXFLAGS += -std=c++14 -Wno-deprecated-declarations" >> ${CRYHOME}/Makefile.local
elif [[ "${basequal}" == e17 ]]; then
  cc=gcc
  cxx=g++
  echo "CXXFLAGS += -std=c++17 -Wno-deprecated-declarations" >> ${CRYHOME}/Makefile.local
elif [[ "${basequal}" == c2 ]]; then
  cc=clang
  cxx=clang++
  echo "CXXFLAGS += -std=c++17 -Wno-deprecated-declarations" >> ${CRYHOME}/Makefile.local
else
  ssi_die "ERROR: unrecognized qualifier ${basequal}"
fi

cd ${CRYHOME}

env CC=${cc} CXX=${cxx} FC=gfortran make || ssi_die "ERROR: make failed."

set +x

if [ ! -d ${CRYHOME}/lib ]
then
   echo "ERROR: failed to create ${CRYHOME}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual} || ssi_die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS}
echo "cry is installed at ${CRYHOME}"

set -x
# fixing embedded path
mv ${CRYHOME}/setup ${CRYHOME}/setup.bak
cat ${CRYHOME}/setup.bak | sed 's%^cd ".*$%cd ${CRYHOME}%' > ${CRYHOME}/setup
set +x

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${CRYHOME}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
